@@ -8,7 +8,7 @@ use Dancer2::Plugin::FormValidator::Processor;
 use Data::FormValidator;
 use Types::Standard qw(InstanceOf);
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 plugin_keywords qw(validate validate_form errors);
 
@@ -31,10 +31,11 @@ sub BUILD {
             name => 'before_template_render',
             code => sub {
                 my $tokens   = shift;
-                my $deferred = $tokens->{deferred}->{$self->config_obj->session_namespace};
 
-                $tokens->{errors} = $deferred->{messages};
-                $tokens->{old}    = $deferred->{old};
+                if (my $deferred = $tokens->{deferred}->{$self->config_obj->session_namespace}) {
+                    $tokens->{errors} = delete $deferred->{messages};
+                    $tokens->{old}    = delete $deferred->{old};
+                }
 
                 return;
             },
@@ -113,7 +114,7 @@ Dancer2::Plugin::FormValidator - validate incoming request in declarative way.
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
